Enum serde_hashkey::Key
source · [−]pub enum Key<F = RejectFloatPolicy>where
F: FloatPolicy,{
Unit,
Bool(bool),
Integer(Integer),
Float(Float<F>),
Bytes(Box<[u8]>),
String(Box<str>),
Seq(Box<[Key<F>]>),
Map(Box<[(Key<F>, Key<F>)]>),
}Expand description
The central key type, which is an in-memory representation of all supported serde-serialized values.
This can be serialized to a type implementing serde::Deserialize using from_key, and deserialized from a type implementing serde::Serialize using to_key. See the corresponding function for documentation.
The type parameter F corresponds to the FloatPolicy in used. It defaults
to RejectFloatPolicy which will cause floats to be rejected.
Examples
use serde_derive::{Deserialize, Serialize};
use serde_hashkey::{to_key, to_key_with_ordered_float};
#[derive(Debug, PartialEq, Eq, Serialize, Deserialize)]
struct Author {
name: String,
age: u32,
}
let key = to_key(&Author {
name: String::from("Jane Doe"),
age: 42,
})?;
// Note: serializing floats will fail under the default policy, but succeed
// under one supporting floats.
assert!(to_key(&42.0f32).is_err());
assert!(to_key_with_ordered_float(&42.0f32).is_ok());Variants
Unit
A unit value.
Bool(bool)
A boolean value.
Integer(Integer)
An integer.
Float(Float<F>)
A 32-bit floating-point number.
Bytes(Box<[u8]>)
A byte array.
String(Box<str>)
A string.
Seq(Box<[Key<F>]>)
A vector.
Map(Box<[(Key<F>, Key<F>)]>)
A map.
Implementations