[−][src]Enum serde_hashkey::Key
The central key type, which is an in-memory representation of all supported serde-serialized values.
This can be serialized to a type implementing serde::Deserialize using from_key, and deserialized from a type implementing serde::Serialize using to_key. See the corresponding function for documentation.
Variants
A unit value.
Bool(bool)A boolean value.
Integer(Integer)An integer.
A byte array.
String(String)A string.
A vector.
A map.
Implementations
impl Key[src]
pub fn normalize(self) -> Key[src]
Normalize the key, making sure that all contained maps are sorted.